Subject: [bug#70395] [PATCH kde-team 37/63] gnu: polkit-qt: Update to 0.200.0.

From: Zheng Junjie <[email-masked]>
Date: Mon, 15 Apr 2024 20:47:14 +0800

* gnu/packages/polkit.scm (polkit-qt): Update to 0.200.0.
[propagated-inputs]: Remove it.
[inputs]: Add qtbase-5.
[arguments]<#:configure-flags>: Update.
[properties]: Set upstream-name.

Change-Id: I69373dc3858fad3160be31a2ebd39a5f52c95294
---
 gnu/packages/polkit.scm | 33 ++++++++++++++++-----------------
 1 file changed, 16 insertions(+), 17 deletions(-)

diff --git a/gnu/packages/polkit.scm b/gnu/packages/polkit.scm
index 337d9b9a73..5f23ed88f3 100644
--- a/gnu/packages/polkit.scm
+++ b/gnu/packages/polkit.scm
@@ -171,30 +171,29 @@ (define-public polkit
 (define-public polkit-qt
   (package
     (name "polkit-qt")
-    (version "1-0.114.0")
+    (version "0.200.0")
     (source (origin
-             (method url-fetch)
-             (uri (string-append
-                   "mirror://kde/stable/polkit-qt-1/"
-                   "polkit-qt-" version ".tar.xz"))
-             (sha256
-              (base32
-               "0zlhwgkqn8g0rkjc7c5n7fbhyyl4jcv0rg5zlbzrb0l88ljg5c1f"))))
+              (method url-fetch)
+              (uri (string-append
+                    "mirror://kde/stable/polkit-qt-1/"
+                    name "-1-" version ".tar.xz"))
+              (sha256
+               (base32
+                "1yvp2s72fgpn5kf1a2ldy0givlmz0z4i1fsh6ylpcard0qf62fsx"))))
     (build-system cmake-build-system)
     (inputs
-     (list polkit))
-    (propagated-inputs
-     (list qtbase-5))
+     (list qtbase-5 polkit))
     (native-inputs
      (list pkg-config))
     (arguments
-     `(#:configure-flags (list (string-append "-DCMAKE_INSTALL_RPATH="
-                                              (assoc-ref %outputs "out")
-                                              "/lib:"
-                                              (assoc-ref %outputs "out")
-                                              "/lib64"))
-       #:tests? #f)) ; there is a test subdirectory, but no test target
+     (list #:configure-flags
+           #~(list (string-append
+                    "-DQT_MAJOR_VERSION="
+                    #$(version-major
+                       (package-version (this-package-input "qtbase")))))
+           #:tests? #f)) ; there is a test subdirectory, but no test target
     (home-page "https://api.kde.org/kdesupport-api/polkit-qt-1-apidocs/")
+    (properties `((upstream-name . "polkit-qt-1")))
     (synopsis "Qt frontend to the polkit library")
     (description "Polkit-qt is a library that lets developers use the
 PolicyKit API through a Qt-styled API.  It is mainly a wrapper around
-- 
2.41.0